summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE5
-rw-r--r--CHANGES3
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in2
-rw-r--r--README2
-rw-r--r--contrib/gregbook/rpng2-win.c2
-rw-r--r--contrib/gregbook/rpng2-x.c2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--pngrutil.c3
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
19 files changed, 38 insertions, 33 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 04e6746dd..17231a6ad 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.6beta04 - September 28, 2011
+Libpng 1.5.6beta04 - October 5, 2011
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -52,7 +52,8 @@ Version 1.5.6beta03 [September 28, 2011]
Revised CMakeLists.txt to work with mingw and removed some material from
CMakeLists.txt that is no longer useful in libpng-1.5.
-Version 1.5.6beta04 [September 28, 2011]
+Version 1.5.6beta04 [October 5, 2011]
+ Fixed typo in Makefile.in and Makefile.am ("-M Wl" should be "-M -Wl")."
Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index 0426b592d..fa7c730b9 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3613,7 +3613,8 @@ Version 1.5.6beta03 [September 28, 2011]
Revised CMakeLists.txt to work with mingw and removed some material from
CMakeLists.txt that is no longer useful in libpng-1.5.
-Version 1.5.6beta04 [September 28, 2011]
+Version 1.5.6beta04 [October 5, 2011]
+ Fixed typo in Makefile.in and Makefile.am ("-M Wl" should be "-M -Wl")."
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/LICENSE b/LICENSE
index 322389c71..808a52f74 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, September 28, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, October 5, 2011, are
Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-September 28, 2011
+October 5, 2011
diff --git a/Makefile.am b/Makefile.am
index c80f0ce89..e6c9adb5e 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -46,7 +46,7 @@ libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@_la_LDFLAGS = -no-undefined -export-dynamic \
if HAVE_LD_VERSION_SCRIPT
# Versioned symbols and restricted exports
if HAVE_SOLARIS_LD
- libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@_la_LDFLAGS += -Wl,-M Wl,libpng.vers
+ libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@_la_LDFLAGS += -Wl,-M -Wl,libpng.vers
else
libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@_la_LDFLAGS += -Wl,--version-script=libpng.vers
endif
diff --git a/Makefile.in b/Makefile.in
index cd7b99800..742320ed9 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -43,7 +43,7 @@ host_triplet = @host@
check_PROGRAMS = pngtest$(EXEEXT) pngvalid$(EXEEXT)
# Versioned symbols and restricted exports
-@HAVE_LD_VERSION_SCRIPT_TRUE@@HAVE_SOLARIS_LD_TRUE@am__append_1 = -Wl,-M Wl,libpng.vers
+@HAVE_LD_VERSION_SCRIPT_TRUE@@HAVE_SOLARIS_LD_TRUE@am__append_1 = -Wl,-M -Wl,libpng.vers
@HAVE_LD_VERSION_SCRIPT_TRUE@@HAVE_SOLARIS_LD_FALSE@am__append_2 = -Wl,--version-script=libpng.vers
# Only restricted exports when possible
@HAVE_LD_VERSION_SCRIPT_FALSE@am__append_3 = -export-symbols libpng.sym
diff --git a/README b/README
index a4c81703b..01f4a0d2a 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.6beta04 - September 28, 2011 (shared library 15.0)
+README for libpng version 1.5.6beta04 - October 5, 2011 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/contrib/gregbook/rpng2-win.c b/contrib/gregbook/rpng2-win.c
index fbdacb59b..223e73740 100644
--- a/contrib/gregbook/rpng2-win.c
+++ b/contrib/gregbook/rpng2-win.c
@@ -590,7 +590,7 @@ int WINAPI WinMain(HINSTANCE hInst, HINSTANCE hPrevInst, PSTR cmd, int showmode)
"(unexpectedly) while reading PNG image file\n");
exit(3);
} else /* if (error) */ {
- // will print error message below
+ /* will print error message below */
}
break;
}
diff --git a/contrib/gregbook/rpng2-x.c b/contrib/gregbook/rpng2-x.c
index b04c5c6b6..7f24b632b 100644
--- a/contrib/gregbook/rpng2-x.c
+++ b/contrib/gregbook/rpng2-x.c
@@ -591,7 +591,7 @@ int main(int argc, char **argv)
"(unexpectedly) while reading PNG image file\n");
exit(3);
} else /* if (error) */ {
- // will print error message below
+ /* will print error message below */
}
break;
}
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 1ef14f726..c48b8373f 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.6beta04 - September 28, 2011
+ libpng version 1.5.6beta04 - October 5, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.6beta04 - September 28, 2011
+ libpng versions 0.97, January 1998, through 1.5.6beta04 - October 5, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -4563,7 +4563,7 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-September 28, 2011
+October 5, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index bcd90af8b..4b2f73469 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "September 28, 2011"
+.TH LIBPNG 3 "October 5, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.6beta04
.SH SYNOPSIS
@@ -977,7 +977,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.6beta04 - September 28, 2011
+ libpng version 1.5.6beta04 - October 5, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -988,7 +988,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.6beta04 - September 28, 2011
+ libpng versions 0.97, January 1998, through 1.5.6beta04 - October 5, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -5541,7 +5541,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-September 28, 2011
+October 5, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -5803,7 +5803,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.6beta04 - September 28, 2011:
+Libpng version 1.5.6beta04 - October 5, 2011:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5826,7 +5826,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, September 28, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, October 5, 2011, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5925,7 +5925,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-September 28, 2011
+October 5, 2011
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 823a6f9eb..fecda795a 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "September 28, 2011"
+.TH LIBPNGPF 3 "October 5, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.6beta04
(private functions)
diff --git a/png.5 b/png.5
index 37e9f8fa6..dab515912 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "September 28, 2011"
+.TH PNG 5 "October 5, 2011"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index cdfb25400..fac0a8f97 100644
--- a/png.c
+++ b/png.c
@@ -645,13 +645,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.6beta04 - September 28, 2011" PNG_STRING_NEWLINE \
+ "libpng version 1.5.6beta04 - October 5, 2011" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.6beta04 - September 28, 2011\
+ return "libpng version 1.5.6beta04 - October 5, 2011\
Copyright (c) 1998-2011 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 851b155d6..29fcc9887 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.6beta04 - September 28, 2011
+ * libpng version 1.5.6beta04 - October 5, 2011
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrutil.c b/pngrutil.c
index 62b3afc9b..0de1fa942 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -3410,6 +3410,9 @@ png_read_finish_row(png_structp png_ptr)
{
png_ptr->row_number = 0;
+ /* TO DO: don't do this if prev_row isn't needed (requires
+ * read-ahead of the next row's filter byte.
+ */
png_memset(png_ptr->prev_row, 0, png_ptr->rowbytes + 1);
do
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 4b2ae9966..50ab8f55e 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.6beta04 - September 28, 2011
+libpng version 1.5.6beta04 - October 5, 2011
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index df243b5d6..6538453f3 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.6beta04 - September 28, 2011
+ * libpng version 1.5.6beta04 - October 5, 2011
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 34e3ab3c0..a4cf77600 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.6beta04 - September 28, 2011
+Makefiles for libpng version 1.5.6beta04 - October 5, 2011
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/png.h b/png.h
index 8f7547c86..abf17e9ec 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.6beta04 - September 28, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.6beta04 - September 28, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -192,7 +192,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, September 28, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -304,7 +304,7 @@
* Y2K compliance in libpng:
* =========================
*
- * September 28, 2011
+ * October 5, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -367,7 +367,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.6beta04"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.6beta04 - September 28, 2011\n"
+ " libpng version 1.5.6beta04 - October 5, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.6beta04 - September 28, 2011
+ * libpng version 1.5.6beta04 - October 5, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.6beta04 - September 28, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.6beta04 - October 5, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -192,7 +192,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, September 28, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.6beta04, October 5, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5